@@ -6,10 +6,12 @@
 #  License, v. 2.0. If a copy of the MPL was not distributed with this
 #  file, You can obtain one at https://mozilla.org/MPL/2.0/.
 #  =========
+
 from .help_text import help_text
 from .register import register
 from .unregister import unregister
 from .unavailiable_in_context import unavailiable_in_context
+from .start import start
 from mcdbot.command import Command, ParamDictKeyEnum, Many
 from mcdbot.discordcontext import DiscordContext
 from loguru import logger
@@ -19,6 +21,7 @@ commands = {
         'register': Command(unavailiable_in_context),
         'unregister': Command(unavailiable_in_context),
         'help': Command(help_text, help_text="Show this help."),
+        'start': Command(help_text, help_text="Makes me sneak into your DMs."),
     },
     DiscordContext.DM_CHANNEL: {
         'register': Command(register,
@@ -33,6 +36,7 @@ commands = {
         'register': Command(unavailiable_in_context),
         'unregister': Command(unavailiable_in_context),
         'help': Command(help_text, help_text="Show this help."),
+        'start': Command(help_text, help_text="Makes me sneak into your DMs."),
     }
 }
 
@@ -66,5 +70,5 @@ for context in commands.keys():
             usage_text[context].append((cmd_full, cmd.help_text))
     text = ''
     for i in usage_text[context]:
-        text += '  ' + i[0].ljust(20, '_') + i[1] + '\n'
+        text += '  ' + i[0].ljust(20, '.') + i[1] + '\n'
     usage_text[context] = text
