@@ -183,10 +183,11 @@ class Mcdbot(discord.Client):
 
                     try:
                         cmd_out = await self.commands[context][cmd].run(self, message, context, split)
-                        await message.channel.send(
-                            f"{message.author.mention} "
-                            f"{cmd_out}"
-                        )
+                        if cmd_out is not None:
+                            await message.channel.send(
+                                f"{message.author.mention} "
+                                f"{cmd_out}"
+                            )
                     except KeyError:
                         await message.channel.send(
                             f"{message.author.mention} "
